@@ -52,9 +52,9 @@ class KeenApi(object):
         url = "{0}/{1}/projects/{2}/events/{3}".format(self.base_url, self.api_version,
                                                        self.project_id,
                                                        event.collection_name)
-        headers = {"Content-Type": "application/json"}
+        headers = {"Content-Type": "application/json", "Authorization": self.write_key}
         payload = event.to_json()
         response = requests.post(url, data=payload, headers=headers)
         if response.status_code != 201:
-            error = response.json
-            raise exceptions.KeenApiError(error)
\ No newline at end of file
+            error = response.json()
+            raise exceptions.KeenApiError(error)
