@@ -6,23 +6,24 @@ from keen.persistence_strategies import BasePersistenceStrategy
 
 __author__ = 'dkador'
 
+
 class Event(object):
     """
     An event in Keen.
     """
 
-    def __init__(self, project_token, collection_name, event_body,
+    def __init__(self, project_id, collection_name, event_body,
                  timestamp=None):
         """ Initializes a new Event.
 
-        :param project_token: the Keen project token to insert the event to
+        :param project_id: the Keen project ID to insert the event to
         :param collection_name: the Keen collection name to insert the event to
         :param event_body: a dict that contains the body of the event to insert
         :param timestamp: optional, specify a datetime to override the
         timestamp associated with the event in Keen
         """
         super(Event, self).__init__()
-        self.project_token = project_token
+        self.project_id = project_id
         self.collection_name = collection_name
         self.event_body = event_body
         self.timestamp = timestamp
@@ -39,38 +40,43 @@ class Event(object):
 
 
 class KeenClient(object):
-    """
-    The Keen Client is the main object to use to interface with Keen. It
-    requires a project ID. Optionally,
-    you can also specify a persistence strategy to elect how events are
-    handled when they're added. The default strategy is to send the event
-    directly to Keen, in-line. This may not always be the best idea, though,
-    so we support other strategies (such as persisting to a local Redis queue
-    for later processing).
+    """ The Keen Client is the main object to use to interface with Keen. It
+    requires a project ID and one or both of write_key and read_key.
+
+    Optionally, you can also specify a persistence strategy to elect how
+    events are handled when they're added. The default strategy is to send
+    the event directly to Keen, in-line. This may not always be the best
+    idea, though, so we support other strategies (such as persisting
+    to a local Redis queue for later processing).
     """
 
-    def __init__(self, project_token, persistence_strategy=None):
+    def __init__(self, project_id, write_key=None, read_key=None,
+                 persistence_strategy=None):
         """ Initializes a KeenClient object.
 
-        :param project_token: the Keen project ID
+        :param project_id: the Keen IO project ID
+        :param write_key: a Keen IO Scoped Key for Writes
+        :param read_key: a Keen IO Scoped Key for Reads
         :param persistence_strategy: optional, the strategy to use to persist
         the event
         """
         super(KeenClient, self).__init__()
 
         # do some validation
-        if not project_token or not isinstance(project_token, basestring):
-            raise exceptions.InvalidProjectIdError(project_token)
+        if not project_id or not isinstance(project_id, str):
+            raise exceptions.InvalidProjectIdError(project_id)
 
         if persistence_strategy:
+            # validate the given persistence strategy
             if not isinstance(persistence_strategy, BasePersistenceStrategy):
                 raise exceptions.InvalidPersistenceStrategyError()
         if not persistence_strategy:
-            keen_api = KeenApi(project_token)
-            persistence_strategy = persistence_strategies\
-            .DirectPersistenceStrategy(keen_api)
+            # setup a default persistence strategy
+            keen_api = KeenApi(project_id, write_key=write_key, read_key=read_key)
+            persistence_strategy = persistence_strategies \
+                .DirectPersistenceStrategy(keen_api)
 
-        self.project_token = project_token
+        self.project_id = project_id
         self.persistence_strategy = persistence_strategy
 
     def add_event(self, collection_name, event_body, timestamp=None):
@@ -85,6 +91,6 @@ class KeenClient(object):
         :param event_body: dict, the body of the event to insert the event to
         :param timestamp: datetime, optional, the timestamp of the event
         """
-        event = Event(self.project_token, collection_name, event_body,
+        event = Event(self.project_id, collection_name, event_body,
                       timestamp=timestamp)
         self.persistence_strategy.persist(event)
